/**
 * 
 */
package org.vcs.bazaar.eclipse;

import java.io.File;

import org.eclipse.core.runtime.IPath;
import org.eclipse.core.runtime.Preferences;
import org.junit.BeforeClass;
import org.vcs.bazaar.client.BazaarClientFactory;
import org.vcs.bazaar.client.BazaarClientPreferences;
import org.vcs.bazaar.client.BazaarPreference;
import org.vcs.bazaar.client.IBazaarClient;
import org.vcs.bazaar.client.testUtils.ExpectedStructureFactory;
import org.vcs.bazaar.client.testUtils.ExpectedWorkingTree;
import org.vcs.bazaar.client.utils.BazaarUtilities;

/**
 * @author Guillermo Gonzalez <guillo.gonzo@gmail.com>
 *
 */
public abstract class AbstractCoreTestCase {

	@BeforeClass
	public static void initialize() {
		final Preferences prefs = EclipseBazaarCore.getDefault().getPluginPreferences();
		if(!EclipseBazaarCore.getDefault().isClientAvailable()) {
			BazaarUtilities.configureBazaarClient(AbstractCoreTestCase.class, "/tests.properties");
			final BazaarClientPreferences clientPrefs = BazaarClientPreferences.getInstance();
			prefs.setValue(BazaarPreference.EXECUTABLE.name(), clientPrefs.getString(BazaarPreference.EXECUTABLE));
			prefs.setValue(BazaarPreference.BZR_EMAIL.name(), clientPrefs.getString(BazaarPreference.BZR_EMAIL));
			prefs.setValue(BazaarPreference.BZR_XMLRPC_PORT.name(), clientPrefs.getString(BazaarPreference.BZR_XMLRPC_PORT));
		}
	}
	
	public static ExpectedWorkingTree createWorkingTree(IPath path) throws Exception {
		File branchDir = path.toFile();
		branchDir.mkdir();
		final ExpectedWorkingTree wt = ExpectedStructureFactory.getWorkingTree();
        wt.materialize(branchDir);
        File[] filesToAdd = branchDir.listFiles();
		IBazaarClient client = BazaarClientFactory.createClient(BazaarClientFactory.getPreferredClientType());
        client.setWorkDir(branchDir);
        client.init(branchDir);
        client.add(filesToAdd);
        client.commit(filesToAdd, "initial import");
        return wt;
	}
}
