/**
 * LICENCSE + COPYRIGHT
 */
package org.vcs.bazaar.eclipse.ui.actions;

import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.IWorkbenchWindow;
import org.eclipse.ui.IWorkbenchWindowActionDelegate;
import org.eclipse.ui.PlatformUI;

/**
 * <p>
 * Base class for actions that may be tied to the workbench.
 * </p>
 * <p>
 * i.e: An action that is displayed in a menu, toolbar, etc
 * </p>
 * 
 * @author Guillermo Gonzalez
 * 
 */
public abstract class WorkbenchAction extends WorkspaceAction implements IWorkbenchWindowActionDelegate {

	protected IWorkbenchWindow window;

	/**
	 * We will cache window object in order to be able to provide parent shell
	 * for the message dialog.
	 * 
	 * @see IWorkbenchWindowActionDelegate#init
	 */
	public void init(IWorkbenchWindow window) {
//		System.out.println(this.getClass().getName() + ":init(window)");
		this.window = window;
	}

	/**
	 * Find and return the shell of the parent "window"
	 * 
	 * @return the parent window Shell or a workbench Shell
	 */
	protected Shell getParentShell() {
		Shell shell;
		if ((window != null) && (window.getShell() != null)) {
			shell = window.getShell();
		} else {
			IWorkbench workbench = PlatformUI.getWorkbench();
			shell = workbench.getActiveWorkbenchWindow().getShell();
		}
		return shell;
	}
	
	protected IWorkbenchPage getActivePage() {
		if(window != null)
			return window.getActivePage();
		IWorkbench wb = PlatformUI.getWorkbench();
		IWorkbenchWindow win = wb.getActiveWorkbenchWindow();
		return win.getActivePage();
		
	}
}
